;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "web-mode" "20260623.932"
  "Major mode for editing web templates."
  '((emacs "24.3.1"))
  :url "https://web-mode.org"
  :commit "aeee2d4c82a791ff69657c1413873bf9265544df"
  :revdesc "aeee2d4c82a7"
  :keywords '("languages")
  :maintainers '(("François-Xavier Bois" . "fxbois@gmail.com")))
